@@ -1,4 +1,3 @@
-# 主要用来处理密码加密
 import binascii
 import hashlib
 
@@ -15,20 +14,17 @@ def make_password(raw_password: str) -> str:
     return binascii.hexlify(password).decode()
 
 
-def verify_password(
-    raw_password: str,
-    password: str,
-) -> bool:
+def verify_password(raw_password: str, password: str) -> bool:
     """
     验证密码是否正确
     :param raw_password:要验证的密码
     :param password:数据库存储的密码
-    :param random_salt_b64:数据库存储的随机盐
-    :return:
     """
     random_salt = settings.SECRET_KEY.encode("utf-8")
-    raw_password = hashlib.pbkdf2_hmac("sha256", raw_password.encode("utf-8"), random_salt, 16)
-    if binascii.hexlify(raw_password).decode() == password:
+    raw_password_bytes = hashlib.pbkdf2_hmac(
+        "sha256", raw_password.encode("utf-8"), random_salt, 16
+    )
+    if binascii.hexlify(raw_password_bytes).decode() == password:
         return True
     else:
         return False
