@@ -6,16 +6,19 @@ import typer
 app = typer.Typer()
 try:
     from fast_tmp.conf import settings
-
-    settings.script_app = app
 except Exception as e:
     print(f"warning:{e}")
     settings = None
+
+
 async def create_superuser(username: str, password: str):
     from tortoise import Tortoise
     await Tortoise.init(config=settings.TORTOISE_ORM)
     from fast_tmp.models import User
-    await User.create(username=username, password=password, is_superuser=True)
+    user = User(username=username, is_superuser=True)
+    user.set_password(password)
+    await user.save()
+
 
 @app.command()
 def createsuperuser(username: str, password: str):
@@ -29,6 +32,9 @@ def createsuperuser(username: str, password: str):
 
 @app.command()
 def startapp():
+    """
+    创建app
+    """
     basedir = os.path.abspath(os.path.dirname(__file__))
     from cookiecutter.main import cookiecutter
     cookiecutter(basedir + "/tpl/app/")
@@ -36,15 +42,32 @@ def startapp():
 
 @app.command()
 def startproject():
+    """
+    创建项目
+    """
     basedir = os.path.abspath(os.path.dirname(__file__))
     from cookiecutter.main import cookiecutter
     cookiecutter(basedir + "/tpl/project")
 
 
+@app.command()
+def staticfile():
+    """
+    离线环境下的swagger静态文件
+    """
+    basedir = os.path.abspath(os.path.dirname(__file__))
+    from cookiecutter.main import cookiecutter
+    cookiecutter(basedir + "/tpl/static")
+
+
 # 导入自定义脚本执行方式
-if settings:
-    for i in settings.EXTRA_SCRIPT:
-        mod = importlib.import_module(i)
+if settings and settings.EXTRA_SETTINGS.get("EXTRA_SCRIPT"):
+    for i in settings.EXTRA_SETTINGS.get("EXTRA_SCRIPT"):
+        path_list = i.split(".")
+        mod = importlib.import_module(".".join(path_list[0:-1]))
+        for k, v in mod.__dict__.items():
+            if k == path_list[-1]:
+                app.command()(v)
 
 
 def main():
